Managing data
=============

The current iteration of the Disease Normalizer stores tens of thousands of symbols, names, cross-references, and other associations. This section describes how to load and refresh data, and details usage of specific backend storage implementations.

.. toctree::

    Loading and updating data<loading_and_updating_data>
    DynamoDB storage backend<dynamodb>
    PostgreSQL storage backend<postgresql>
